@@ -10,7 +10,8 @@
 
 #include <iostream>
 #include <pango/pango.h>
-#include <freetype/freetype.h>
+#include <ft2build.h>
+#include FT_FREETYPE_H
 
 /** Generate the Postscript commands to draw the glyph
   * using the font in pPangoCtx.
