@@ -15,8 +15,7 @@
 
 #include <ft2build.h>
 #include FT_FREETYPE_H
-
-#include <freetype/ftglyph.h>
+#include FT_GLYPH_H
 
 /** Manage FT_Glyph by insuring that FT_Glyph is handled correctly.
  */
